@@ -1,5 +1,5 @@
-from retask.task import Task
-from retask.queue import Queue
+from retask import Task
+from retask import Queue
 import time
 queue = Queue('example')
 info1 = {'user': 'Fedora planet', 'url': 'http://planet.fedoraproject.org'}
