@@ -1,5 +1,4 @@
-from retask.task import Task
-from retask.queue import Queue
+from retask import Queue
 queue = Queue('example')
 queue.connect()
 while queue.length != 0:
