@@ -9,7 +9,7 @@ This module contains the set of Retask's exceptions.
 """
 
 class RetaskException(RuntimeError):
-    """Some ambigous exception occured"""
+    """Some ambiguous exception occurred"""
 
 class ConnectionError(RetaskException):
-    """A Connection error occurred."""
\ No newline at end of file
+    """A Connection error occurred."""
